NAME

ClarID::Tools - ClarID: A Human-Readable and Compact Identifier Specification for Biomedical Metadata Integration

DESCRIPTION

We recommend using the included command-line interface.

For a better description, please read the following documentation:

General:

https://cnag-biomedical-informatics.github.io/clarid-tools

Command-Line Interface:

https://github.com/CNAG-Biomedical-Informatics/clarid-tools#readme

CITATION

The author requests that any published work that utilizes ClarID-Tools includes a cite to the following reference:

Rueda, M. and Gut, I.G. (2026). ClarID: a human-readable and compact identifier specification for biomedical metadata integration. Journal of Biomedical Semantics 17, 9. https://doi.org/10.1186/s13326-026-00349-6.

AUTHOR

Written by Manuel Rueda, PhD. Info about CNAG can be found at https://www.cnag.eu.

COPYRIGHT

This PERL file is copyrighted. See the LICENSE file included in this distribution.